@@ -117,16 +117,14 @@ void DPMS::onWakeupFromIdle()
 
 void DPMS::onIdleTimeout(std::chrono::milliseconds /*timeout*/)
 {
-    Q_EMIT startFade();
+    // Do not inhibit anything even if idleTimeout reaches because we are inhibit
+    if (!m_inhibitScreen && isSupported()) {
+        Q_EMIT startFade();
+    }
 }
 
 void DPMS::turnOffOnIdleTimeout()
 {
-    // Do not inhibit anything even if idleTimeout reaches because we are inhibit
-    if (m_inhibitScreen) {
-        return;
-    }
-
     const int keyboardBrightness = backend()->keyboardBrightness();
     if (keyboardBrightness > 0) {
         m_oldKeyboardBrightness = keyboardBrightness;
@@ -174,27 +172,33 @@ void DPMS::triggerImpl(const QVariantMap &args)
 
 bool DPMS::loadAction(const PowerDevil::ProfileSettings &profileSettings)
 {
-    if (!profileSettings.turnOffDisplayWhenIdle()) {
-        return false;
-    }
-
     m_idleTimeoutWhenUnlocked = std::chrono::seconds(profileSettings.turnOffDisplayIdleTimeoutSec());
     m_idleTimeoutWhenLocked = std::chrono::seconds(profileSettings.turnOffDisplayIdleTimeoutWhenLockedSec());
     m_lockBeforeTurnOff = profileSettings.lockBeforeTurnOffDisplay();
 
-    if (m_idleTimeoutWhenUnlocked >= 0ms) {
-        m_idleTimeoutWhenUnlocked = std::max(m_idleTimeoutWhenUnlocked, s_minIdleTimeoutWhenUnlocked);
+    if (!profileSettings.turnOffDisplayWhenIdle() || m_idleTimeoutWhenUnlocked < 0ms) {
+        onProfileUnload();
+        return false;
     }
-    if (m_idleTimeoutWhenLocked >= 0ms) {
-        // Allow (almost) immediate turn-off upon entering the lockscreen, but not when already locked
-        m_idleTimeoutWhenActivatingLock = std::max(m_idleTimeoutWhenLocked, s_minIdleTimeoutWhenActivatingLock);
-        m_idleTimeoutWhenLocked = std::max(m_idleTimeoutWhenLocked, s_minIdleTimeoutWhenLocked);
+
+    m_idleTimeoutWhenUnlocked = std::max(m_idleTimeoutWhenUnlocked, s_minIdleTimeoutWhenUnlocked);
+
+    if (m_idleTimeoutWhenLocked < 0ms) {
+        m_idleTimeoutWhenLocked = m_idleTimeoutWhenUnlocked;
     }
+    // Allow (almost) immediate turn-off upon entering the lockscreen, but not when already locked
+    m_idleTimeoutWhenActivatingLock = std::max(m_idleTimeoutWhenLocked, s_minIdleTimeoutWhenActivatingLock);
+    m_idleTimeoutWhenLocked = std::max(m_idleTimeoutWhenLocked, s_minIdleTimeoutWhenLocked);
 
     registerStandardIdleTimeout();
     return true;
 }
 
+void DPMS::onProfileUnload()
+{
+    m_idleTimeoutWhenUnlocked = std::chrono::milliseconds(-1);
+}
+
 void DPMS::onUnavailablePoliciesChanged(PowerDevil::PolicyAgent::RequiredPolicies policies)
 {
     m_inhibitScreen = policies & PowerDevil::PolicyAgent::ChangeScreenSettings;
@@ -205,6 +209,10 @@ void DPMS::registerStandardIdleTimeout()
     unregisterIdleTimeouts();
     m_isActivatingLock = false;
 
+    if (m_idleTimeoutWhenUnlocked < 0ms) { // action created, but not loaded
+        return;
+    }
+
     if (PowerDevil::PolicyAgent::instance()->screenLockerActive()) {
         registerIdleTimeout(m_idleTimeoutWhenLocked);
     } else {
@@ -217,6 +225,10 @@ void DPMS::onScreenLockerActiveChanged(bool active)
     unregisterIdleTimeouts();
     m_isActivatingLock = active && !m_isAboutToSuspend;
 
+    if (m_idleTimeoutWhenUnlocked < 0ms) { // action created, but not loaded
+        return;
+    }
+
     if (m_isActivatingLock) {
         // entering lockscreen - fast display turn-off if the config calls for it
         registerIdleTimeout(m_idleTimeoutWhenActivatingLock);
