@@ -1,22 +1,8 @@
 /*
- * Copyright 2020 Kai Uwe Broulik <kde@broulik.de>
- * Copyright 2021 David Redondo <kde@david-redondo.de>
+ * SPDX-FileCopyrightText: 2020 Kai Uwe Broulik <kde@broulik.de>
+ * SPDX-FileCopyrightText: 2021 David Redondo <kde@david-redondo.de>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #pragma once
@@ -33,17 +19,16 @@ namespace BundledActions
 class PowerProfile : public PowerDevil::Action, protected QDBusContext
 {
     Q_OBJECT
-    Q_DISABLE_COPY(PowerProfile)
     Q_CLASSINFO("D-Bus Interface", "org.kde.Solid.PowerManagement.Actions.PowerProfile")
 
     Q_PROPERTY(QStringList profileChoices READ profileChoices NOTIFY profileChoicesChanged)
     Q_PROPERTY(QString currentProfile READ currentProfile NOTIFY currentProfileChanged)
 
 public:
-    explicit PowerProfile(QObject *parent, const QVariantList &);
+    explicit PowerProfile(QObject *parent);
     ~PowerProfile() override;
 
-    bool loadAction(const KConfigGroup &config) override;
+    bool loadAction(const PowerDevil::ProfileSettings &profileSettings) override;
 
     QStringList profileChoices() const;
     QString currentProfile() const;
@@ -62,10 +47,7 @@ Q_SIGNALS:
     void profileHoldsChanged(const QList<QVariantMap> &holds);
 
 protected:
-    void onProfileLoad() override;
-    void onWakeupFromIdle() override;
-    void onIdleTimeout(int msec) override;
-    void onProfileUnload() override;
+    void onProfileLoad(const QString &previousProfile, const QString &newProfile) override;
     void triggerImpl(const QVariantMap &args) override;
     bool isSupported() override;
 private Q_SLOTS:
