@@ -1,25 +1,10 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Dario Freddi <drf@kde.org>                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2010 Dario Freddi <drf@kde.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
-
-#ifndef POWERDEVILCORE_H
-#define POWERDEVILCORE_H
+#pragma once
 
 #include "powerdevilbackendinterface.h"
 
@@ -27,33 +12,39 @@
 #include <QSet>
 #include <QStringList>
 
-#include <QDBusMessage>
-#include <QDBusError>
 #include <QDBusContext>
+#include <QDBusError>
+#include <QDBusMessage>
 #include <QDBusObjectPath>
 
 #include <QSocketNotifier>
 
 #include <KSharedConfig>
 
+#include "batterycontroller.h"
+#include "lidcontroller.h"
+#include "powerdevilcore_export.h"
+#include "suspendcontroller.h"
+
 namespace KActivities
 {
-    class Consumer;
+class Consumer;
 } // namespace KActivities
 
 class QDBusServiceWatcher;
 class QTimer;
 class KNotification;
 
-namespace Solid {
+namespace Solid
+{
 class Battery;
 }
 
 namespace PowerDevil
 {
-
 class BackendInterface;
 class Action;
+class GlobalSettings;
 
 struct WakeupInfo {
     QString service;
@@ -62,14 +53,14 @@ struct WakeupInfo {
     qint64 timeout;
 };
 
-class Q_DECL_EXPORT Core : public QObject, protected QDBusContext
+class POWERDEVILCORE_EXPORT Core : public QObject, protected QDBusContext
 {
     Q_OBJECT
     Q_DISABLE_COPY(Core)
     Q_CLASSINFO("D-Bus Interface", "org.kde.Solid.PowerManagement")
 
 public:
-    explicit Core(QObject* parent);
+    explicit Core(QObject *parent);
     ~Core() override;
 
     void reloadProfile(int state);
@@ -80,7 +71,7 @@ public:
 
     enum class ChargeNotificationFlag {
         None,
-        NotifyWhenAcPluggedIn
+        NotifyWhenAcPluggedIn,
     };
     Q_DECLARE_FLAGS(ChargeNotificationFlags, ChargeNotificationFlag)
     Q_FLAG(ChargeNotificationFlags)
@@ -88,6 +79,11 @@ public:
     bool emitBatteryChargePercentNotification(int currentPercent, int previousPercent, const QString &udi = QString(), ChargeNotificationFlags flags = {});
 
     BackendInterface *backend();
+    SuspendController *suspendController();
+    BatteryController *batteryController();
+    LidController *lidController();
+
+    Action *action(const QString actionId);
 
     // More...
 
@@ -130,7 +126,9 @@ Q_SIGNALS:
     void chargeStopThresholdChanged(int threshold);
 
 private:
-    void registerActionTimeout(Action *action, int timeout);
+    void initActions();
+    void unloadAllActiveActions();
+    void registerActionTimeout(Action *action, std::chrono::milliseconds timeout);
     void unregisterActionTimeouts(Action *action);
     void handleLowBattery(int percent);
     void handleCriticalBattery(int percent);
@@ -152,11 +150,14 @@ private:
     int m_chargeStopThreshold = 100;
 
     BackendInterface *m_backend = nullptr;
+    std::unique_ptr<SuspendController> m_suspendController;
+    std::unique_ptr<BatteryController> m_batteryController;
+    std::unique_ptr<LidController> m_lidController;
 
     QDBusServiceWatcher *m_notificationsWatcher = nullptr;
     bool m_notificationsReady = false;
 
-    KSharedConfigPtr m_profilesConfig;
+    GlobalSettings *m_globalSettings = nullptr;
 
     QString m_currentProfile;
 
@@ -171,7 +172,7 @@ private:
     KActivities::Consumer *const m_activityConsumer;
 
     // Idle time management
-    QHash< Action*, QList< int > > m_registeredActionTimeouts;
+    QHash<Action *, QList<int>> m_registeredActionTimeouts;
     QSet<Action *> m_pendingResumeFromIdleActions;
     bool m_pendingWakeupEvent;
 
@@ -182,17 +183,20 @@ private:
     QSocketNotifier *m_timerFdSocketNotifier = nullptr;
 
     // Activity inhibition management
-    QHash< QString, int > m_sessionActivityInhibit;
-    QHash< QString, int > m_screenActivityInhibit;
+    QHash<QString, int> m_sessionActivityInhibit;
+    QHash<QString, int> m_screenActivityInhibit;
+
+    QHash<QString, Action *> m_actionPool;
+    QStringList m_activeActions;
 
 private Q_SLOTS:
     void onBackendReady();
-    void onAcAdapterStateChanged(PowerDevil::BackendInterface::AcAdapterState);
-    void onBatteryChargePercentChanged(int,const QString&);
-    void onBatteryChargeStateChanged(int,const QString&);
+    void onAcAdapterStateChanged(BatteryController::AcAdapterState);
+    void onBatteryChargePercentChanged(int, const QString &);
+    void onBatteryChargeStateChanged(int, const QString &);
     void onBatteryRemainingTimeChanged(qulonglong);
     void onSmoothedBatteryRemainingTimeChanged(qulonglong);
-    void onKIdleTimeoutReached(int,int);
+    void onKIdleTimeoutReached(int, int);
     void onResumingFromIdle();
     void onDeviceAdded(const QString &udi);
     void onDeviceRemoved(const QString &udi);
@@ -207,5 +211,3 @@ private Q_SLOTS:
 };
 
 }
-
-#endif // POWERDEVILCORE_H
